import { defineColumns, defineOperationBtns, useFormDialog, useTable } from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
import { useQueryClient } from '@tanstack/vue-query';
import { setOSSLink } from '@/utils';
import {
  CustomerApplyFileTypeListItem,
  EnterpriseApplyFileUtils,
} from '@/components/commonView/utils';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import * as enterpriseApplyFileServices from '@/services/api/EnterpriseApplyFile';
import { BaseDeclareEnterpriseTableViewColumns, EnterpriseTypeText } from '@/constants';

export const rewardGrantRegisterColumns = computed(() =>
  defineColumns([
    ...BaseDeclareEnterpriseTableViewColumns,
    {
      id: '9',
      enCode: 'a',
      name: '财政拨付金额',
    },
    {
      id: '10',
      enCode: 'a',
      name: '财政拨付已登记',
    },
    {
      id: '11',
      enCode: 'a',
      name: '最近登记日期',
    },
    {
      id: '12',
      enCode: 'a',
      name: '财政拨付登记状态',
    },
    {
      id: '13',
      enCode: 'a',
      name: '平台拨付金额',
    },
    {
      id: '14',
      enCode: 'a',
      name: '平台拨付已登记',
    },
    {
      id: '15',
      enCode: 'a',
      name: '最近登记日期',
    },
    {
      id: '16',
      enCode: 'a',
      name: '平台拨付登记状态',
    },
  ])
);

type UseDeclareEnterpriseTableOptions = {
  id?: Ref<string>;
  applyMonth?: Ref<string>;
};

export function useDeclareEnterpriseTable(options: UseDeclareEnterpriseTableOptions = {}) {
  const { id, applyMonth } = options;

  const {
    getDataSource: getList,
    proTableProps,
    paginationState,
    extraParamState,
    reset,
  } = useTable(
    async ({ pageIndex, pageSize }, extraParamState) => {
      try {
        let params: API.GetParkBountyApplyInfoInput = {
          pageModel: {
            rows: pageSize,
            page: pageIndex,
            orderInput: extraParamState.orderInput,
          },
          searchKeyWord: extraParamState.searchKeyWord,
          parkBountyApplyId: id.value,
        };
        let res = await parkBountyApplyServices.getOutCheckParkBountyApplyDetailList(params);
        return res;
      } catch (error) {}
    },
    {
      defaultExtraParams: {
        orderInput: [{ property: 'parkBountyApplyId', order: OrderInputType.Desc }],
        searchKeyWord: '',
      },
      columnsRenderProps: {
        authType: { type: 'enum', valueEnum: EnterpriseTypeText },
        licenseUrl: {
          type: 'urlV2',
          formatter: (row: API.UserCertificationAuditListDto) => setOSSLink(row.licenseUrl),
        },
        applyAmount: { type: 'money' },
      },
    }
  );

  const queryClient = useQueryClient();
  const { dialogProps, handleAdd, editForm, dialogState } = useFormDialog({
    defaultFormParams: {
      list: [] as CustomerApplyFileTypeListItem[],
      companyId: '',
    },
  });
  async function openDialog(row: API.ParkBountyApplyDetailInfo) {
    try {
      const applyFilesRes = await queryClient.ensureQueryData({
        queryKey: [
          'enterpriseApplyFileServices/getCustomerUploadApplyFiles',
          row.enterpriseId,
          applyMonth.value,
        ],
        queryFn: async () => {
          return await enterpriseApplyFileServices.getCustomerUploadApplyFiles({
            enterpriseId: row.enterpriseId,
            withMonth: applyMonth.value,
          });
        },
      });
      const lastUploadEnterPactFile = await queryClient.ensureQueryData({
        queryKey: ['enterpriseApplyFileServices/getCustomerUploadApplyFiles', row.enterpriseId],
        queryFn: async () => {
          return await parkBountyApplyServices.getEnterpriseLastUploadEnterPactFileNew({
            companyId: row.enterpriseId,
          });
        },
      });

      const applyUploadFiles = await parkBountyApplyServices.getEnterpriseParkApplyUploadFiles({
        companyId: row.enterpriseId,
        parkBountyApplyId: id.value,
      });
      handleAdd({
        list: EnterpriseApplyFileUtils.initParkCollectFileListApplyFiles(
          applyUploadFiles,
          applyFilesRes.items,
          lastUploadEnterPactFile
        ),
        companyId: row.enterpriseId,
      });
    } catch (error) {}
  }

  const operationBtns = defineOperationBtns([
    {
      data: {
        enCode: 'detailBtn',
        name: '详情',
      },
      emits: {
        onClick: (row) => openDialog(row),
      },
    },
  ]);

  return {
    getList,
    proTableProps,
    paginationState,
    extraParamState,
    reset,
    openDialog,
    dialogProps,
    dialogState,
    editForm,
    operationBtns,
  };
}
